
Authors
=======

* Ionel Cristian Mărieș - http://blog.ionelmc.ro
* Areski Belaid - http://areskibelaid.com/
* ??? - https://github.com/artscoop
* Rick van Hattem - http://w.wol.ph/
* Benjamin Wohlwend - https://github.com/piquadrat
* Trbs - https://github.com/trbs
* John Lau - https://github.com/jolks
* ??? - https://github.com/gabn88
